Very Demotivational - Work Harder, Not Smarter. - demotivational posters - Cheezburger
Description: Work Harder, Not Smarter.

## FASHION CONSCIOUS

Favorite
Tags

- fashion
- bomb
- extremist

By cartaig
- -
Share: -

FASHION CONSCIOUS now even muslim extremists can be trendy

0 Comments

## Looks Like He Shot It

Favorite
Tags

- nokia
- guns
- chuck norris
- funny

By Unknown
- -
Share: -
0 Comments

## Sometimes You're Just Not That Good

Favorite
Tags

- failure
- bad idea
- soccer
- funny

Via: Google
- -
Share: -
0 Comments

## FERRARIS

Favorite
Recaption See All Captions
Tags

- car
- fast
- ferrari
- idiots
- money

By Santa_be_naughty
- -
Share: -

FERRARIS when you need a 700 horsepower v12 engine to drive 60 mph down a highway to work.

0 Comments

## SUPERGLUE

Favorite
Tags

- baby sitter
- cheap
- hilarious
- super glue

By ChemicalKate
- -
Share: -

SUPERGLUE cheaper than a babysitter

0 Comments

## DO YOU HAVE ANY IDEA

Favorite
Tags

- clock
- hilarious
- idea
- time
- wtf

By fareon
- -
Share: -

DO YOU HAVE ANY IDEA what time it is? you should have been home hours ago

0 Comments

## TOKYO DRIFT

Favorite
View Fullscreen
Tags

- barbie car
- hilarious
- tokyo drift

By _C_A_T_
- -
Share: -

TOKYO DRIFT you can't do it in a barbie car

0 Comments
Loading more posts...

- Prev
- 1
- 2
- 3
- 4
- 5
- Next

## Make a Meme

#### Use one of our LOLBuilders. Get Internet famous. Prosper.

- Add a caption
- Make a Look-Alike
- Add more than a caption
- Make a chart
- Make a Demotivational Poster
- Send in a FAIL
- Add a Breaking News Headline
- Make a Comic Strip
- Make a Rage Comic

## Make a Site

#### Cheezburger Sites, the fastest site you'll ever make.

Pick Your Site Name

Tell me more

## Your friends would love to see this too!

### You can now let your Facebook friends see when you add new favorites to your Cheezburger page.

Add to Timeline
No Thanks!

## Everything is better with friends!

### Connect to Facebook to share laughs, create fun, and prove once and for all who is the funniest in your group.

Connect Now
No Thanks!
×

## Keyboard Navigation

### Use your keyboard to navigate the site!

- `J` `K` Next / previous Post
- `F` Favorite
- `S` Share on Facebook
- `?` Menu

## Invite Your Friends!

### Cheezburger is even more awesome when you share with your friends.

Invite with Facebook

## Submit

Select a file to upload
OR paste in the url to an image
OR paste in the url to a video
Title
Description
URL for this content (if any)